﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using Telerik.Windows.Controls;
using System.Windows.Media.Imaging;
using System.Windows.Threading;

namespace TreeViewWithContextMenuExample
{
    public partial class MainPage : UserControl
    {
        ObservableCollection<ContextMenuItem> solutionMenuItems = GenerateSolutionContextMenu();
        ObservableCollection<ContextMenuItem> projectMenuItems = GenerateProjectContextMenu();
        ObservableCollection<ContextMenuItem> xamlMenuItems = GenerateXAMLContextMenu();
        ObservableCollection<ContextMenuItem> csMenuItems = GenerateCSContextMenu();

        public MainPage()
        {
            InitializeComponent();

            radTreeView.ItemsSource = GenerateTreeViewData();
        }

        private ObservableCollection<File> GenerateTreeViewData()
        {
            CSFile appCSFile = new CSFile("App.xaml.cs");
            appCSFile.IsCodeBehindFile = true;

            XAMLFile appXAMLFile = new XAMLFile("App.xaml");
            appXAMLFile.Children.Add(appCSFile);

            CSFile mainCSFile = new CSFile("MainPage.xaml.cs");
            mainCSFile.IsCodeBehindFile = true;

            XAMLFile mainXAMLFile = new XAMLFile("MainPage.xaml");
            mainXAMLFile.Children.Add(mainCSFile);

            ProjectFile contextMenuProjectFile = new ProjectFile("TreeViewWithContextMenu");
            contextMenuProjectFile.Children.Add(appXAMLFile);
            contextMenuProjectFile.Children.Add(mainXAMLFile);

            CSFile modelsCSFile = new CSFile("Models.cs");

            appCSFile = new CSFile("App.xaml.cs");
            appCSFile.IsCodeBehindFile = true;

            appXAMLFile = new XAMLFile("App.xaml");
            appXAMLFile.Children.Add(appCSFile);

            mainCSFile = new CSFile("MainPage.xaml.cs");
            mainCSFile.IsCodeBehindFile = true;

            mainXAMLFile = new XAMLFile("MainPage.xaml"); 
            mainXAMLFile.Children.Add(mainCSFile);

            ProjectFile masterDetailProjectFile = new ProjectFile("TreeViewMasterDetail");
            masterDetailProjectFile.Children.Add(appXAMLFile);
            masterDetailProjectFile.Children.Add(mainXAMLFile);
            masterDetailProjectFile.Children.Add(modelsCSFile);

            SolutionFile solutionFile = new SolutionFile("Solution 'TreeView' (2 projects)");
            solutionFile.Children.Add(contextMenuProjectFile);
            solutionFile.Children.Add(masterDetailProjectFile);

            return new ObservableCollection<File>() { solutionFile };
        }

        private void RadContextMenu_Opened(object sender, RoutedEventArgs e)
        {
            RadTreeViewItem item = radContextMenu.GetClickedElement<RadTreeViewItem>();

            if (item.Item is SolutionFile)
                radContextMenu.ItemsSource = solutionMenuItems;
            else if (item.Item is ProjectFile)
                radContextMenu.ItemsSource = projectMenuItems;
            else if (item.Item is XAMLFile || (item.Item as CSFile).IsCodeBehindFile)
                radContextMenu.ItemsSource = xamlMenuItems;
            else radContextMenu.ItemsSource = csMenuItems;
        }

        private static ObservableCollection<ContextMenuItem> GenerateSolutionContextMenu()
        {
            ContextMenuItem build = new ContextMenuItem();
            build.Header = "Build Solution";
            build.ImagePath = "Images/build.png";

            ContextMenuItem rebuild = new ContextMenuItem();
            rebuild.Header = "Rebuild Solution";

            ContextMenuItem clean = new ContextMenuItem();
            clean.Header = "Clean Solution";

            ContextMenuItem separator = new ContextMenuItem();
            separator.IsSeparator = true;

            ContextMenuItem properties = new ContextMenuItem();
            properties.Header = "Properties";
            properties.ImagePath = "Images/properties.png";

            ObservableCollection<ContextMenuItem> items = new ObservableCollection<ContextMenuItem>();
            items.Add(build);
            items.Add(rebuild);
            items.Add(clean);
            items.Add(separator);
            items.Add(properties);

            return items;
        }

        private static ObservableCollection<ContextMenuItem> GenerateProjectContextMenu()
        {
            ContextMenuItem build = new ContextMenuItem();
            build.Header = "Build";
            build.ImagePath = "Images/build.png";

            ContextMenuItem rebuild = new ContextMenuItem();
            rebuild.Header = "Rebuild";

            ContextMenuItem clean = new ContextMenuItem();
            clean.Header = "Clean";

            ContextMenuItem viewInBrowser = new ContextMenuItem();
            viewInBrowser.Header = "View in Browser";
            viewInBrowser.ImagePath = "Images/explorer.png";

            ContextMenuItem separator = new ContextMenuItem();
            separator.IsSeparator = true;

            ContextMenuItem properties = new ContextMenuItem();
            properties.Header = "Properties";
            properties.ImagePath = "Images/properties.png";

            ObservableCollection<ContextMenuItem> items = new ObservableCollection<ContextMenuItem>();
            items.Add(build);
            items.Add(rebuild);
            items.Add(clean);
            items.Add(viewInBrowser);
            items.Add(separator);
            items.Add(properties);

            return items;
        }

        private static ObservableCollection<ContextMenuItem> GenerateXAMLContextMenu()
        {
            ContextMenuItem open = new ContextMenuItem();
            open.Header = "Open";
            open.ImagePath = "Images/open.png";

            ContextMenuItem openWith = new ContextMenuItem();
            openWith.Header = "Open With...";

            ContextMenuItem separator = new ContextMenuItem();
            separator.IsSeparator = true;

            ContextMenuItem viewCode = new ContextMenuItem();
            viewCode.Header = "View Code";
            viewCode.ImagePath = "Images/viewCode.png";

            ContextMenuItem viewDesigner = new ContextMenuItem();
            viewDesigner.Header = "View Designer";
            viewDesigner.ImagePath = "Images/viewDesigner.png";

            ContextMenuItem properties = new ContextMenuItem();
            properties.Header = "Properties";
            properties.ImagePath = "Images/properties.png";

            ObservableCollection<ContextMenuItem> items = new ObservableCollection<ContextMenuItem>();
            items.Add(open);
            items.Add(openWith);
            items.Add(separator);
            items.Add(viewCode);
            items.Add(viewDesigner);
            items.Add(separator);
            items.Add(properties);

            return items;
        }

        private static ObservableCollection<ContextMenuItem> GenerateCSContextMenu()
        {
            ContextMenuItem open = new ContextMenuItem();
            open.Header = "Open";
            open.ImagePath = "Images/open.png";

            ContextMenuItem openWith = new ContextMenuItem();
            openWith.Header = "Open With...";

            ContextMenuItem separator = new ContextMenuItem();
            separator.IsSeparator = true;

            ContextMenuItem viewCode = new ContextMenuItem();
            viewCode.Header = "View Code";
            viewCode.ImagePath = "Images/viewCode.png";

            ContextMenuItem properties = new ContextMenuItem();
            properties.Header = "Properties";
            properties.ImagePath = "Images/properties.png";

            ObservableCollection<ContextMenuItem> items = new ObservableCollection<ContextMenuItem>();
            items.Add(open);
            items.Add(openWith);
            items.Add(separator);
            items.Add(viewCode);
            items.Add(separator);
            items.Add(properties);

            return items;
        }
    }
}
